==> haskell-binary-tagged-0.1.4.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-binary-tagged/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.0
id: binary-tagged-0.1.4.0-07ba9310509de53d819f2eb756aa7f9b
key: binar_EMMnfSvcDP7KuMUMDiFq8V
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.4.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.4.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.4.0
hs-libraries: HSbinary-tagged-0.1.4.0-EMMnfSvcDP7KuMUMDiFq8V
depends:
    SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    generics-sop-0.2.1.0-7239eda8d6e847745310ee1c6aedf3ba
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.1.4.0-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-binary-tagged/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.0
id: binary-tagged-0.1.4.0-9e366a431b003c1c13d38569e01bb834
key: binar_2cKR5YVKK7lAO7okwbrQty
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.4.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.4.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.4.0
hs-libraries: HSbinary-tagged-0.1.4.0-2cKR5YVKK7lAO7okwbrQty
depends:
    SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    generics-sop-0.2.1.0-7239eda8d6e847745310ee1c6aedf3ba
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
